@@ -2,7 +2,7 @@ from math import sin, cos
 from typing import Tuple, Sequence, Union
 
 from zodipy.models import model_registry
-from zodipy._component_labels import ComponentLabel
+from zodipy._labels import Label
 import numpy as np
 import astropy.constants as const
 
@@ -39,8 +39,8 @@ def get_component_density_grid(
         3D grid of the density of the component.
     """
 
-    ipd_model = model_registry.get_model(model)
-    component_class = ipd_model.components[ComponentLabel(component)]
+    _model = model_registry.get_model(model)
+    component_class = _model.get_initialized_component(Label(component))
 
     x_helio = np.linspace(-xy_lim, xy_lim, n)
     y_helio = x_helio.copy()
@@ -55,17 +55,17 @@ def get_component_density_grid(
 
     R_prime = np.sqrt(XX_prime ** 2 + YY_prime ** 2 + ZZ_prime ** 2)
     Z_prime = (
-        XX_prime * sin(component_class.Ω) * sin(component_class.i)
-        - YY_prime * cos(component_class.Ω) * sin(component_class.i)
+        XX_prime * sin(component_class.Omega) * sin(component_class.i)
+        - YY_prime * cos(component_class.Omega) * sin(component_class.i)
         + ZZ_prime * cos(component_class.i)
     )
 
-    X_earth_prime = earth_coords - component_class.X_component[0]
+    X_earth_prime = earth_coords - component_class.X_0[0]
     θ_prime = np.arctan2(YY_prime, ZZ_prime) - np.arctan2(
         X_earth_prime[1], X_earth_prime[0]
     )
 
-    density_grid = component_class.get_density(
+    density_grid = component_class.compute_density(
         R_prime=R_prime, Z_prime=Z_prime, θ_prime=θ_prime
     )
 
