@@ -6,7 +6,7 @@ from zodipy import component_parameters
 
 model_registry.register_model(
     name="DIRBE",
-    components=[
+    component_labels=[
         Label.CLOUD,
         Label.BAND1,
         Label.BAND2,
@@ -30,10 +30,9 @@ model_registry.register_model(
     ),
 )
 
-
 model_registry.register_model(
     name="Planck13",
-    components=[
+    component_labels=[
         Label.CLOUD,
         Label.BAND1,
         Label.BAND2,
@@ -49,13 +48,13 @@ model_registry.register_model(
         "T_0": source_parameters.T_0_K98,
         "delta": source_parameters.delta_K98,
     },
-    doc=("The Interplanetary Dust Model used in the Planck 2013 analysis"),
+    doc=("The Interplanetary Dust Model used in the Planck 2013 analysis."),
 )
 
 
 model_registry.register_model(
     name="Planck15",
-    components=[
+    component_labels=[
         Label.CLOUD,
         Label.BAND1,
         Label.BAND2,
@@ -69,13 +68,13 @@ model_registry.register_model(
         "T_0": source_parameters.T_0_K98,
         "delta": source_parameters.delta_K98,
     },
-    doc=("The Interplanetary Dust Model used in the Planck 2015 analysis"),
+    doc=("The Interplanetary Dust Model used in the Planck 2015 analysis."),
 )
 
 
 model_registry.register_model(
     name="Planck18",
-    components=[
+    component_labels=[
         Label.CLOUD,
         Label.BAND1,
         Label.BAND2,
@@ -89,5 +88,5 @@ model_registry.register_model(
         "T_0": source_parameters.T_0_K98,
         "delta": source_parameters.delta_K98,
     },
-    doc=("The Interplanetary Dust Model used in the Planck 2018 analysis"),
+    doc=("The Interplanetary Dust Model used in the Planck 2018 analysis."),
 )
